<?php
namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Amenity;
use App\Models\Neighborhood;
use App\Models\Property;
use App\Models\PropertyAmenity;
use App\Models\PropertyImage;
use Illuminate\Http\Request;

Class PropertyController extends Controller{
    /* ====================== VIEWS START ====================== */
    public function index(){ 
        $data = [];
        $data["data"] = Property::paginate(15);
        return view('admin/manage/properties', $data);
    }

    public function create(){ 
        $data = [];
        $data["places"] = Neighborhood::all();
        $data["amenities"] = Amenity::all();
        return view('admin/create/properties', $data);
    }
    
    public function edit($id)
    {
        $data = [];
        $data["places"] = Neighborhood::all();
        $data["data"] = Property::find($id);
        $data["amenities"] = Amenity::all();
        $data["property_amenities"] = PropertyAmenity::where("property_id", $id)->get();
        $data["property_images"] = PropertyImage::where("property_id", $id)->get();
        return view('admin/update/properties', $data);
    }
    /* ====================== VIEW END ====================== */

    /* ======================== POST FUNCTIONS  ======================= */
    public function store(Request $request){
        $query = null;
        $inputs = $request->except("properties_amenities");
        $query = Property::create($inputs);
        if($query){
            
            $property = Property::find($query->id);
            $property->amenities()->attach($request->input("properties_amenities"));

            return response()->json(['message' => "Record Added!"]);
        } else {
            return $this->senderror("Something went wrong!", 404);
        }
    }
    public function update(Request $request, $id)
    {
        $query = null;
        $inputs = $request->except(["_method", "properties_amenities"]);
        $query = Property::where("id", $id)->update($inputs);

        $property = Property::find($id);
        $property->amenities()->detach();
        $property->amenities()->attach($request->input("properties_amenities"));

        if($query) {
            return response()->json(['message' => "Record Updated"]);
        } else {
            return $this->senderror("Something went wrong!", 404); 
        }
    }
    public function destroy($id){
        $query = null;
        
        $property = Property::find($id);
        $property->amenities()->detach();

        $query = Property::where("id", $id)->delete();
	    if($query) {
            return response()->json(['message' => "Record Deleted!"]);
        } else {
            return $this->senderror("Something went wrong!", 404);
        }
    }



    public function storeImage(Request $request){
        $query = null;
        
        $inputs = $request->except(['file']);
        
        $request->validate([
            "file" => 'required|image|mimes:jpeg,png,jpg,gif,svg'
        ]);
        
        $image_src = time().'.'.$request->file('file')->extension();
        $request->file('file')->move(public_path('website/property_images'), $image_src);
        $inputs["image_src"] = $image_src;

        $query = PropertyImage::create($inputs);

        if($query){
            return response()->json(['message' => "Record Added!"]);
	    } else {
            if(file_exists(public_path("website/property_images/".$inputs["image_src"]))){
                unlink(public_path("website/property_images/".$inputs["image_src"]));
            }
            return $this->senderror("Something went wrong!", 404);
	    }
    }
    public function destroyImage($id){
        $query = null;
        $product_image = PropertyImage::find($id);
        if(file_exists(public_path("website/property_images/".$product_image->image_src))){
            unlink(public_path("website/property_images/".$product_image->image_src));
        }
        $query = PropertyImage::where("id", $id)->delete();
	    if($query) {
            return response()->json(['message' => "Record Deleted!"]);
        } else {
            return $this->senderror("Something went wrong!", 404);
        }
    }
    /* ====================== POST FUNCTIONS END ====================== */
}