<?php
namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Property;
use App\Models\Rfeature;
use App\Models\Room;
use App\Models\RoomFeature;
use App\Models\RoomImage;
use Illuminate\Http\Request;

Class PropertyRoomController extends Controller{
    /* ====================== VIEWS START ====================== */
    public function index(){ 
        $data = [];
        $data["data"] = Room::paginate(15);
        return view('admin/manage/property_rooms', $data);
    }

    public function create(){ 
        $data = [];
        $data["properties"] = Property::all();
        $data["features"] = Rfeature::all();
        return view('admin/create/property_rooms', $data);
    }
    
    public function edit($id)
    {
        $data = [];
        $data["properties"] = Property::all();
        $data["features"] = Rfeature::all();

        $data["data"] = Room::find($id);
        $data["room_features"] = RoomFeature::where("room_id", $id)->get();
        $data["room_images"] = RoomImage::where("room_id", $id)->get();
        return view('admin/update/property_rooms', $data);
    }
    /* ====================== VIEW END ====================== */

    /* ======================== POST FUNCTIONS  ======================= */
    public function store(Request $request){
        $query = null;
        $inputs = $request->except("room_features");
        $query = Room::create($inputs);
        if($query){
            
            $property = Room::find($query->id);
            $property->features()->attach($request->input("room_features"));

            return response()->json(['message' => "Record Added!"]);
        } else {
            return $this->senderror("Something went wrong!", 404);
        }
    }
    public function update(Request $request, $id)
    {
        $query = null;
        $inputs = $request->except(["_method", "room_features"]);
        $query = Room::where("id", $id)->update($inputs);

        $property = Room::find($id);
        $property->features()->detach();
        $property->features()->attach($request->input("room_features"));

        if($query) {
            return response()->json(['message' => "Record Updated"]);
        } else {
            return $this->senderror("Something went wrong!", 404); 
        }
    }
    public function destroy($id){
        $query = null;
        
        $room = Room::find($id);
        $room->features()->detach();

        $query = Room::where("id", $id)->delete();
	    if($query) {
            return response()->json(['message' => "Record Deleted!"]);
        } else {
            return $this->senderror("Something went wrong!", 404);
        }
    }

    public function storeImage(Request $request){
        $query = null;
        
        $inputs = $request->except(['file']);
        
        $request->validate([
            "file" => 'required|image|mimes:jpeg,png,jpg,gif,svg'
        ]);
        
        $image_src = time().'.'.$request->file('file')->extension();
        $request->file('file')->move(public_path('website/property_images'), $image_src);
        $inputs["image_src"] = $image_src;

        $query = RoomImage::create($inputs);

        if($query){
            return response()->json(['message' => "Record Added!"]);
	    } else {
            if(file_exists(public_path("website/property_images/".$inputs["image_src"]))){
                unlink(public_path("website/property_images/".$inputs["image_src"]));
            }
            return $this->senderror("Something went wrong!", 404);
	    }
    }
    public function destroyImage($id){
        $query = null;
        $product_image = RoomImage::find($id);
        if(file_exists(public_path("website/property_images/".$product_image->image_src))){
            unlink(public_path("website/property_images/".$product_image->image_src));
        }
        $query = RoomImage::where("id", $id)->delete();
	    if($query) {
            return response()->json(['message' => "Record Deleted!"]);
        } else {
            return $this->senderror("Something went wrong!", 404);
        }
    }
    /* ====================== POST FUNCTIONS END ====================== */
}