<?php
namespace App\Http\Controllers\Auth;

use App\Models\GeneralSetting;
use App\Http\Controllers\Controller;
use App\Models\Profile;
use App\Models\User;
use Illuminate\Foundation\Auth\AuthenticatesUsers;
use Illuminate\Support\Facades\Auth;
use Illuminate\Http\Request;

class LoginController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Login Controller
    |--------------------------------------------------------------------------
    |
    | This controller handles authenticating users for the application and
    | redirecting them to your home screen. The controller uses a trait
    | to conveniently provide its functionality to your applications.
    |
    */

    use AuthenticatesUsers;

    /**
     * Where to redirect users after login / registration.
     *
     * @var string
     */
    // public $redirectTo = 'admin';

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        // $this->middleware('admin.guest')->except('logout');
    }

    public function index() { // ----- > First Page 
        $data = [];
        return view('website/auth/index', $data);
    }

    /**
     * Show the application's login form.
     *
     * @return \Illuminate\Http\Response
     */
    public function showLoginForm()
    {
        $pageTitle = "User Login";
        return view('website.auth.login', compact('pageTitle'));
    }

    /**
     * Show the application's register form.
     *
     * @return \Illuminate\Http\Response
     */
    public function showRegisterForm()
    {
        $pageTitle = "User Register";
        return view('website.auth.register', compact('pageTitle'));
    }

    /**
     * Get the guard to be used during authentication.
     *
     * @return \Illuminate\Contracts\Auth\StatefulGuard
     */
    protected function guard()
    {
        return Auth::guard('user');
    }

    public function username()
    {
        return 'email';
    }

    public function login(Request $request)
    {

        $this->validateLogin($request);
        // If the class is using the ThrottlesLogins trait, we can automatically throttle
        // the login attempts for this application. We'll key this by the username and
        // the IP address of the client making these requests into this application.
        if (method_exists($this, 'hasTooManyLoginAttempts') &&
            $this->hasTooManyLoginAttempts($request)) {
            $this->fireLockoutEvent($request);
            return $this->sendLockoutResponse($request);
        }

        if ($this->attemptLogin($request)) {
            return $this->sendLoginResponse($request);
        }

        // If the login attempt was unsuccessful we will increment the number of attempts
        // to login and redirect the user back to the login form. Of course, when this
        // user surpasses their maximum number of attempts they will get locked out.
        $this->incrementLoginAttempts($request);

        return $this->sendFailedLoginResponse($request);
    }

    public function register(Request $request) {
        $query ="";
        $user_inputs = $request->only('email', 'password');
        $query = User::where("email", $user_inputs["email"])->first();
        if(!$query){
            $query = User::create($user_inputs);
            if($query){
                $user_profile = $request->only('fullname');
                $user_profile["user_id"] = $query->id;
                $query2 = Profile::create($user_profile);
                if($query2){
                    return response()->json(['message' => "You have successfully registered. Please login to continue."]);
                } else {
                    return $this->senderror("Something Went Wrong!", 404);
                }
            }
        } else {
            return $this->senderror("Email already exists!", 404);
        }
        return $this->senderror("Access Denied!", 404);
    }


    public function logout(Request $request)
    {
        $this->guard('user')->logout();
        $request->session()->invalidate();
        return $this->loggedOut($request) ?: redirect('/');
    }

    public function resetPassword()
    {
        $pageTitle = 'Account Recovery';
        return view('user.reset', compact('pageTitle'));
    }
}